@@ -47,6 +47,7 @@ from .client import (
     UpdateManagedSchemaResponse,
     backend_response_failed,
 )
+from .errors import is_upload_in_progress_error
 
 LAMBDA_CLIENT_NAME = "lambda"
 AWS_PROFILE_ENV_KEY = "AWS_PROFILE"
@@ -110,7 +111,11 @@ class LambdaClient(Client):
 
         if backend_response_failed(resp):
             err = BackendError(resp.data)
+
             err.permanent = True
+            if is_upload_in_progress_error(resp.data):
+                err.permanent = False
+
             raise err
 
         body = decode_body(resp)
@@ -301,6 +306,7 @@ class LambdaClient(Client):
                 rules=BulkUploadStatistics(**body.get("rules", default_stats)),
                 policies=BulkUploadStatistics(**body.get("policies", default_stats)),
                 queries=BulkUploadStatistics(**body.get("queries", default_stats)),
+                data_models=BulkUploadStatistics(**body.get("dataModels", default_stats)),
             ),
         )
 
